﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Media.Imaging; 
using System.Windows.Shapes;
using Silverlight_Media_Player.AzureImagesWCFService;
using System.Xml;
using System.Xml.Linq;
using System.Linq.Expressions;
using Microsoft.SharePoint.Client;
using ClientOM = Microsoft.SharePoint.Client; 

namespace Silverlight_Media_Player
{
    public partial class MainPage : UserControl
    {
        List<ImageInfo> listOfImages = new List<ImageInfo>();
        GetAzureStorageDataClient myServiceProxy = new GetAzureStorageDataClient();

        string imageName = "";
        string imageURI = "";

        string azureImageName = "";
        string azureImageURI = "";
        string azureImageCoolness = "";
        string azureImageNotes = "";
        string mySPSite = "";

        public MainPage()
        {
            InitializeComponent();
        }

        private void btnLoadImage_Click(object sender, RoutedEventArgs e)
        {
            myServiceProxy.GetDataCompleted += new EventHandler<GetDataCompletedEventArgs>(myServiceProxy_GetDataCompleted);
            myServiceProxy.GetDataAsync(); 
        }

        void myServiceProxy_GetDataCompleted(object sender, GetDataCompletedEventArgs e)
        {
            cmbobxImages.Items.Clear(); 

            var returnBlobData = e.Result;
            XDocument blobXMLData = XDocument.Parse(returnBlobData);

            foreach (var p in blobXMLData.Descendants("Blob"))
            {
                ImageInfo tempImage = new ImageInfo();
                tempImage.imageName = p.Element("Name").Value;
                tempImage.imageURL = p.Element("Url").Value;
                listOfImages.Add(tempImage);

                cmbobxImages.Items.Add(p.Element("Name").Value);

                imageName = p.Element("Name").Value;
                imageURI = p.Element("Url").Value;
            };
        }

        private void cmbobxImages_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            UpdateUIControlProperties();

            Image azureImage = new Image();
            azureImage.Width = 387;
            azureImage.Height = 299; 
            azureImage.Stretch = Stretch.UniformToFill; 
            Uri azureURI = new Uri(imageURI, UriKind.Absolute);
            ImageSource azureImageSource = new System.Windows.Media.Imaging.BitmapImage(azureURI);
            azureImage.SetValue(Image.SourceProperty, azureImageSource);

            azureImageCanvas.Children.Clear(); 
            azureImageCanvas.Children.Add(azureImage);
        }

        private void UpdateUIControlProperties()
        {
            string fileNameFilter = ""; 
            fileNameFilter = cmbobxImages.SelectedValue.ToString();

            var query = from filteredImage in listOfImages
                        where filteredImage.imageName == fileNameFilter
                        select filteredImage;

            foreach (var item in query)
            {
                imageName = item.imageName;
                imageURI = item.imageURL; 
            }

            imageName = imageName.Substring(0, imageName.LastIndexOf("."));
            txtbxName.Text = imageName;
            txtbxLink.Text = imageURI.ToString();
        }

        private void btnClearFields_Click(object sender, RoutedEventArgs e)
        {
            txtbxNotes.Text = "";
        }

        private void btnSaveToSharePoint_Click(object sender, RoutedEventArgs e)
        {
            ConnectToSharePoint(); 
        }

        private void ConnectToSharePoint()
        {
            azureImageName = txtbxName.Text;
            azureImageURI = txtbxLink.Text;
            azureImageCoolness = cmbobxPriority.SelectionBoxItem.ToString();  
            azureImageNotes = txtbxNotes.Text;
            mySPSite = "http://blueyonderdemo";

            ClientOM.ClientContext mySPContext = new ClientContext(mySPSite);
            ClientOM.List azureImageList = mySPContext.Web.Lists.GetByTitle("Azure Images");
            mySPContext.Load(mySPContext.Web);
            mySPContext.Load(azureImageList);

            ListItemCreationInformation newImageRecord = new ListItemCreationInformation();
            ClientOM.ListItem newImage = azureImageList.AddItem(newImageRecord);

            newImage["Title"] = azureImageName;
            newImage["Link"] = azureImageURI;
            newImage["Coolness"] = azureImageCoolness;
            newImage["Notes"] = azureImageNotes;
            newImage.Update(); 

            mySPContext.ExecuteQueryAsync(OnItemAddedSucceeded, OnItemAddedFailed);
        }

        private void OnItemAddedSucceeded(Object sender, ClientOM.ClientRequestSucceededEventArgs args)
        {
            MessageBox.Show("SharePoint List Updated!"); 
        }

        private void OnItemAddedFailed(Object sender, ClientOM.ClientRequestFailedEventArgs args)
        {
            Dispatcher.BeginInvoke(() => ShowErrorMessages(args)); 
        }

        private void ShowErrorMessages(ClientRequestFailedEventArgs args)
        {
            MessageBox.Show(args.Message + " " + args.ErrorValue); 
        }
    }
}

 